==> owlapi-api-5.0.5-sources.jar: org/semanticweb/owlapi/model/HasSignature.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.model;

import static org.semanticweb.owlapi.util.OWLAPIStreamUtils.*;

import java.util.Set;
import java.util.stream.Stream;

/**
 * An interface to an object which has a signature
 * 
 * @author Matthew Horridge, Stanford University, Bio-Medical Informatics
 *         Research Group
 * @since 3.4.6
 */
public interface HasSignature {

    /**
     * Gets the signature of this object. The default implementation is an
     * empty, modifiable set.
     * <p>
     * For ontologies, the signature of an ontology is the set of entities that
     * are used to build axioms and annotations in the ontology. (See <a href=
     * "http://www.w3.org/TR/owl2-syntax/#Entities.2C_Literals.2C_and_Anonymous_Individuals"
     * >The OWL 2 Structural Specification</a>)
     * <p>
     * For ontology changes, this is the signature of the axiom being
     * added/removed or the annotation being added/removed, or empty.
     * 
     * @return A set of entities that represents the signature of this object.
     *         Changes are not reflected back.
     * @deprecated use the stream method
     */
    @Deprecated
    default Set<OWLEntity> getSignature() {
        return asSet(signature());
    }

    /**
     * @return Stream of the signature of this object.
     */
    default Stream<OWLEntity> signature() {
        return empty();
    }
}

==> owlapi-api-5.1.16-sources.jar: org/semanticweb/owlapi/model/HasSignature.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.model;

import static org.semanticweb.owlapi.util.OWLAPIStreamUtils.asSet;
import static org.semanticweb.owlapi.util.OWLAPIStreamUtils.empty;

import java.util.Set;
import java.util.stream.Stream;

/**
 * An interface to an object which has a signature
 *
 * @author Matthew Horridge, Stanford University, Bio-Medical Informatics Research Group
 * @since 3.4.6
 */
public interface HasSignature {

    /**
     * Gets the signature of this object. The default implementation is an empty, modifiable set.
     * <p>
     * For ontologies, the signature of an ontology is the set of entities that are used to build
     * axioms and annotations in the ontology. (See <a href=
     * "http://www.w3.org/TR/owl2-syntax/#Entities.2C_Literals.2C_and_Anonymous_Individuals" >The
     * OWL 2 Structural Specification</a>)
     * <p>
     * For ontology changes, this is the signature of the axiom being added/removed or the
     * annotation being added/removed, or empty.
     *
     * @return A set of entities that represents the signature of this object. Changes are not
     *         reflected back.
     * @deprecated use {@link #signature()}
     */
    @Deprecated
    default Set<OWLEntity> getSignature() {
        return asSet(unsortedSignature());
    }

    /**
     * @return Stream of the signature of this object.
     */
    default Stream<OWLEntity> signature() {
        return empty();
    }

    /**
     * @return signature without sorting requirement. For immutable objects, this does not
     *         necessarily differ from the signature. Mutable objects, such as OWLOntology
     *         instances, can provide an unsorted signature faster.
     */
    default Stream<OWLEntity> unsortedSignature() {
        return signature();
    }
}
